# Release History

## 0.3.0 (2018-12-19)

* Added: climate data interface
* Modified: PV model now expects inputs as W, not kW
* Fixed: minor improvements in `trigon.py` (sunrise/sunset times now take sun radius into consideration; clipping of zeros to avoid NaNs)

## 0.2.1 (2018-09-07)

* Fix: clip maximum panel output

## 0.2.0 (2018-08-10)

* PyPI package
* Minor bug fixes

## 0.1.0 (2016-09-01)

* First version
